@@ -1,4 +1,4 @@
-# Copyright (c) 2023, 2024, Oracle and/or its affiliates.
+# Copyright (c) 2023, 2025, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -47,7 +47,6 @@ from typing import (
     Any,
     AsyncGenerator,
     BinaryIO,
-    Callable,
     Dict,
     List,
     Mapping,
@@ -59,6 +58,7 @@ from typing import (
 )
 
 from .. import version
+from .._scripting import get_local_infile_filenames
 from ..constants import (
     ClientFlag,
     FieldType,
@@ -66,7 +66,6 @@ from ..constants import (
     ServerCmd,
     ServerFlag,
     flag_is_set,
-    raise_warning_against_deprecated_cursor_class,
 )
 from ..errors import (
     ConnectionTimeoutError,
@@ -81,6 +80,7 @@ from ..errors import (
     WriteTimeoutError,
     get_exception,
 )
+from ..protocol import EOF_STATUS, ERR_STATUS, LOCAL_INFILE_STATUS, OK_STATUS
 from ..types import (
     BinaryProtocolType,
     DescriptionType,
@@ -99,26 +99,21 @@ from ..utils import (
     warn_ciphersuites_deprecated,
     warn_tls_version_deprecated,
 )
-from ._decorating import cmd_refresh_verify_options
+from ._decorating import cmd_refresh_verify_options, handle_read_write_timeout
 from .abstracts import MySQLConnectionAbstract, MySQLCursorAbstract, ServerInfo
 from .charsets import charsets
 from .cursor import (
     MySQLCursor,
     MySQLCursorBuffered,
     MySQLCursorBufferedDict,
-    MySQLCursorBufferedNamedTuple,
     MySQLCursorBufferedRaw,
     MySQLCursorDict,
-    MySQLCursorNamedTuple,
     MySQLCursorPrepared,
     MySQLCursorPreparedDict,
-    MySQLCursorPreparedNamedTuple,
-    MySQLCursorPreparedRaw,
     MySQLCursorRaw,
 )
 from .logger import logger
 from .network import MySQLTcpSocket, MySQLUnixSocket
-from .utils import handle_read_write_timeout
 
 
 class MySQLConnection(MySQLConnectionAbstract):
@@ -159,7 +154,7 @@ class MySQLConnection(MySQLConnectionAbstract):
 
         # Set converter class
         try:
-            self.set_converter_class(self._converter_class)
+            self.converter_class = self._converter_class
         except TypeError as err:
             raise AttributeError(
                 "Converter classA should be a subclass of "
@@ -203,7 +198,7 @@ class MySQLConnection(MySQLConnectionAbstract):
             "_os": platform["version"],
         }
 
-        self._connection_attrs.update((default_conn_attrs))
+        self._connection_attrs.update(default_conn_attrs)
 
     async def _execute_query(self, query: str) -> ResultType:
         """Execute a query.
@@ -219,7 +214,7 @@ class MySQLConnection(MySQLConnectionAbstract):
         """Get the handshake from the MySQL server."""
         packet = await self._socket.read()
         logger.debug("Protocol::Handshake packet: %s", packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
 
         self._handshake = self._protocol.parse_handshake(packet)
@@ -271,14 +266,14 @@ class MySQLConnection(MySQLConnectionAbstract):
             self._client_flags |= ClientFlag.SSL
 
         if self._handshake["capabilities"] & ClientFlag.PLUGIN_AUTH:
-            self.set_client_flags([ClientFlag.PLUGIN_AUTH])
+            self.client_flags = [ClientFlag.PLUGIN_AUTH]
 
         if self._handshake["capabilities"] & ClientFlag.CLIENT_QUERY_ATTRIBUTES:
             self._server_info.query_attrs_is_supported = True
-            self.set_client_flags([ClientFlag.CLIENT_QUERY_ATTRIBUTES])
+            self.client_flags = [ClientFlag.CLIENT_QUERY_ATTRIBUTES]
 
         if self._handshake["capabilities"] & ClientFlag.MULTI_FACTOR_AUTHENTICATION:
-            self.set_client_flags([ClientFlag.MULTI_FACTOR_AUTHENTICATION])
+            self.client_flags = [ClientFlag.MULTI_FACTOR_AUTHENTICATION]
 
     async def _do_auth(self) -> None:
         """Authenticate with the MySQL server.
@@ -368,11 +363,11 @@ class MySQLConnection(MySQLConnectionAbstract):
         packet, an error will be raised. If the packet is neither an OK or an Error
         packet, InterfaceError will be raised.
         """
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             ok_pkt = self._protocol.parse_ok(packet)
             self._handle_server_status(ok_pkt["status_flag"])
             return ok_pkt
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
         raise InterfaceError("Expected OK packet")
 
@@ -393,11 +388,11 @@ class MySQLConnection(MySQLConnectionAbstract):
         packet, an error will be raised. If the packet is neither and OK or an Error
         packet, InterfaceError will be raised.
         """
-        if packet[4] == 254:
+        if packet[4] == EOF_STATUS:
             eof = self._protocol.parse_eof(packet)
             self._handle_server_status(eof["status_flag"])
             return eof
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
         raise InterfaceError("Expected EOF packet")
 
@@ -409,7 +404,49 @@ class MySQLConnection(MySQLConnectionAbstract):
         write_timeout: Optional[int] = None,
     ) -> OkPacketType:
         """Handle a LOAD DATA INFILE LOCAL request."""
+        if self._local_infile_filenames is None:
+            self._local_infile_filenames = get_local_infile_filenames(self._query)
+            if not self._local_infile_filenames:
+                raise InterfaceError(
+                    "No `LOCAL INFILE` statements found in the client's request. "
+                    "Check your request includes valid `LOCAL INFILE` statements."
+                )
+        elif not self._local_infile_filenames:
+            raise InterfaceError(
+                "Got more `LOCAL INFILE` responses than number of `LOCAL INFILE` "
+                "statements specified in the client's request. Please, report this "
+                "issue to the development team."
+            )
+
         file_name = os.path.abspath(filename)
+        file_name_from_request = os.path.abspath(self._local_infile_filenames.popleft())
+
+        # Verify the file location specified by `filename` from client's request exists
+        if not os.path.exists(file_name_from_request):
+            raise InterfaceError(
+                f"Location specified by filename {file_name_from_request} "
+                "from client's request does not exist."
+            )
+
+        # Verify the file location specified by `filename` from server's response exists
+        if not os.path.exists(file_name):
+            raise InterfaceError(
+                f"Location specified by filename {file_name} from server's "
+                "response does not exist."
+            )
+
+        # Verify the `filename` specified by server's response matches the one from
+        # the client's request.
+        try:
+            if not os.path.samefile(file_name, file_name_from_request):
+                raise InterfaceError(
+                    f"Filename {file_name} from the server's response is not the same "
+                    f"as filename {file_name_from_request} from the "
+                    "client's request."
+                )
+        except OSError as err:
+            raise InterfaceError from err
+
         if os.path.islink(file_name):
             raise OperationalError("Use of symbolic link is not allowed")
         if not self._allow_local_infile and not self._allow_local_infile_in_path:
@@ -478,16 +515,16 @@ class MySQLConnection(MySQLConnectionAbstract):
         """
         if not packet or len(packet) < 4:
             raise InterfaceError("Empty response")
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             return self._handle_ok(packet)
-        if packet[4] == 251:
+        if packet[4] == LOCAL_INFILE_STATUS:
             filename = packet[5:].decode()
             return await self._handle_load_data_infile(
                 filename, read_timeout, write_timeout
             )
-        if packet[4] == 254:
+        if packet[4] == EOF_STATUS:
             return self._handle_eof(packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
 
         # We have a text result set
@@ -520,9 +557,9 @@ class MySQLConnection(MySQLConnectionAbstract):
 
         Returns a dict()
         """
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             return self._protocol.parse_binary_prepare_ok(packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
         raise InterfaceError("Expected Binary OK packet")
 
@@ -545,11 +582,11 @@ class MySQLConnection(MySQLConnectionAbstract):
         """
         if not packet or len(packet) < 4:
             raise InterfaceError("Empty response")
-        if packet[4] == 0:
+        if packet[4] == OK_STATUS:
             return self._handle_ok(packet)
-        if packet[4] == 254:
+        if packet[4] == EOF_STATUS:
             return self._handle_eof(packet)
-        if packet[4] == 255:
+        if packet[4] == ERR_STATUS:
             raise get_exception(packet)
 
         # We have a binary result set
@@ -668,6 +705,55 @@ class MySQLConnection(MySQLConnectionAbstract):
             return False
         return True
 
+    async def reset_session(
+        self,
+        user_variables: Optional[Dict[str, Any]] = None,
+        session_variables: Optional[Dict[str, Any]] = None,
+    ) -> None:
+        """Clears the current active session
+
+        This method resets the session state, if the MySQL server is 5.7.3
+        or later active session will be reset without re-authenticating.
+        For other server versions session will be reset by re-authenticating.
+
+        It is possible to provide a sequence of variables and their values to
+        be set after clearing the session. This is possible for both user
+        defined variables and session variables.
+        This method takes two arguments user_variables and session_variables
+        which are dictionaries.
+
+        Raises OperationalError if not connected, InternalError if there are
+        unread results and InterfaceError on errors.
+        """
+        if not await self.is_connected():
+            raise OperationalError("MySQL Connection not available.")
+
+        if not await self.cmd_reset_connection():
+            try:
+                await self.cmd_change_user(
+                    self._user,
+                    self._password,
+                    self._database,
+                    self._charset.charset_id,
+                    self._password1,
+                    self._password2,
+                    self._password3,
+                    self._oci_config_file,
+                    self._oci_config_profile,
+                    self._openid_token_file,
+                )
+            except ProgrammingError:
+                await self.reconnect()
+
+        cur = await self.cursor()
+        if user_variables:
+            for key, value in user_variables.items():
+                await cur.execute(f"SET @`{key}` = %s", (value,))
+        if session_variables:
+            for key, value in session_variables.items():
+                await cur.execute(f"SET SESSION `{key}` = %s", (value,))
+        await cur.close()
+
     async def ping(
         self, reconnect: bool = False, attempts: int = 1, delay: int = 0
     ) -> None:
@@ -711,17 +797,6 @@ class MySQLConnection(MySQLConnectionAbstract):
             pass  # Getting an exception would mean we are disconnected.
 
     async def close(self) -> None:
-        """Close the connection.
-
-        It closes any opened cursor associated to this connection, and closes the
-        underling socket connection.
-
-        `MySQLConnection.close()` is a synonymous for `MySQLConnection.disconnect()`
-        method name and more commonly used.
-
-        This method tries to send a `QUIT` command and close the socket. It raises
-        no exceptions.
-        """
         with contextlib.suppress(Error):
             for cursor in tuple(self._cursors):
                 await cursor.close()
@@ -734,7 +809,7 @@ class MySQLConnection(MySQLConnectionAbstract):
             await self._socket.close_connection()
         self._socket = None
 
-    disconnect: Callable[[], Any] = close
+    disconnect = close
 
     async def cursor(
         self,
@@ -743,7 +818,6 @@ class MySQLConnection(MySQLConnectionAbstract):
         prepared: Optional[bool] = None,
         cursor_class: Optional[Type[MySQLCursorAbstract]] = None,
         dictionary: Optional[bool] = None,
-        named_tuple: Optional[bool] = None,
         read_timeout: Optional[int] = None,
         write_timeout: Optional[int] = None,
     ) -> MySQLCursor:
@@ -751,8 +825,8 @@ class MySQLConnection(MySQLConnectionAbstract):
 
         By default, MySQLCursor is returned. Depending on the options while
         connecting, a buffered and/or raw cursor is instantiated instead.
-        Also depending upon the cursor options, rows can be returned as dictionary or
-        named tuple.
+        Also depending upon the cursor options, rows can be returned as a dictionary
+        or a tuple.
 
         It is possible to also give a custom cursor through the cursor_class
         parameter, but it needs to be a subclass of
@@ -795,8 +869,6 @@ class MySQLConnection(MySQLConnectionAbstract):
             cursor_type |= 2
         if dictionary is True:
             cursor_type |= 4
-        if named_tuple is True:
-            cursor_type |= 8
         if prepared is True:
             cursor_type |= 16
 
@@ -807,22 +879,15 @@ class MySQLConnection(MySQLConnectionAbstract):
             3: MySQLCursorBufferedRaw,
             4: MySQLCursorDict,
             5: MySQLCursorBufferedDict,
-            8: MySQLCursorNamedTuple,
-            9: MySQLCursorBufferedNamedTuple,
             16: MySQLCursorPrepared,
-            18: MySQLCursorPreparedRaw,
             20: MySQLCursorPreparedDict,
-            24: MySQLCursorPreparedNamedTuple,
         }
         try:
-            raise_warning_against_deprecated_cursor_class(
-                cursor_name=types[cursor_type].__name__
-            )
             return (types[cursor_type])(self, read_timeout, write_timeout)
         except KeyError:
-            args = ("buffered", "raw", "dictionary", "named_tuple", "prepared")
+            args = ("buffered", "raw", "dictionary", "prepared")
             criteria = ", ".join(
-                [args[i] for i in range(5) if cursor_type & (1 << i) != 0]
+                [args[i] for i in range(4) if cursor_type & (1 << i) != 0]
             )
             raise ValueError(
                 f"Cursor not available with given criteria: {criteria}"
@@ -875,7 +940,7 @@ class MySQLConnection(MySQLConnectionAbstract):
         if not self.unread_result:
             raise InternalError("No result set available")
 
-        rows: Tuple[List[Tuple[Any, ...]], Optional[EofPacketType]] = ([], None)
+        rows = ([], None)  # type: ignore[var-annotated]
         try:
             read_timeout = kwargs.get("read_timeout", None)
             if binary:
@@ -965,6 +1030,11 @@ class MySQLConnection(MySQLConnectionAbstract):
             if isinstance(query, str):
                 query = query.encode()
             query = bytearray(query)
+
+        # Set/Reset internal state related to query execution
+        self._query = query
+        self._local_infile_filenames = None
+
         # Prepare query attrs
         charset = self._charset.name if self._charset.name != "utf8mb4" else "utf8"
         packet = bytearray()
