@@ -75,17 +75,22 @@ COMMAND_CLASSES = {
 if DistWheel is not None:
     COMMAND_CLASSES["bdist_wheel"] = DistWheel
 
+cext_src_files = [
+    "src/exceptions.c",
+    "src/mysql_capi.c",
+    "src/mysql_capi_conversion.c",
+    "src/mysql_connector.c",
+    "src/force_cpp_linkage.cc",
+]
+
+if os.name == "nt":
+    cext_src_files.append("src/version_info.rc")
+
 # C extensions
 EXTENSIONS = [
     Extension(
         "_mysql_connector",
-        sources=[
-            "src/exceptions.c",
-            "src/mysql_capi.c",
-            "src/mysql_capi_conversion.c",
-            "src/mysql_connector.c",
-            "src/force_cpp_linkage.cc",
-        ],
+        sources=cext_src_files,
         include_dirs=["src/include"],
     ),
 ]
@@ -151,11 +156,11 @@ def main() -> None:
         extras_require={
             "dns-srv": ["dnspython==2.6.1"],
             "gssapi": ["gssapi==1.8.3"],
-            "fido2": ["fido2==1.1.2"],
+            "webauthn": ["fido2==1.1.2"],
             "telemetry": [
-                "opentelemetry-api==1.18.0",
-                "opentelemetry-sdk==1.18.0",
-                "opentelemetry-exporter-otlp-proto-http==1.18.0",
+                "opentelemetry-api==1.33.1",
+                "opentelemetry-sdk==1.33.1",
+                "opentelemetry-exporter-otlp-proto-http==1.33.1",
             ],
         },
     )
@@ -166,13 +171,19 @@ def copy_metadata_files() -> None:
     parent directory to the current directory.
     """
     for filename in METADATA_FILES:
-        shutil.copy(pathlib.Path(os.getcwd(), f"../{filename}"), pathlib.Path(f"./"))
+        # if file is not in current directory, then try to load it from one level above
+        if not os.path.exists(
+            pathlib.Path(os.getcwd(), f"./{filename}")
+        ) and os.path.exists(pathlib.Path(os.getcwd(), f"../{filename}")):
+            shutil.copy(
+                pathlib.Path(os.getcwd(), f"../{filename}"), pathlib.Path(f"./")
+            )
 
 
 def get_long_description() -> str:
     """Extracts a long description from the README.rst file that is suited for this specific package.
     """
-    with open(pathlib.Path(os.getcwd(), "../README.rst")) as file_handle:
+    with open(pathlib.Path(os.getcwd(), "./README.rst")) as file_handle:
         # The README.rst text is meant to be shared by both mysql and mysqlx packages, so after getting it we need to
         # parse it in order to remove the bits of text that are not meaningful for this package (mysql)
         long_description = file_handle.read()
@@ -218,10 +229,4 @@ def remove_metadata_files() -> None:
 
 if __name__ == "__main__":
     copy_metadata_files()
-
-    try:
-        main()
-    except Exception as err:
-        raise err
-    finally:
-        remove_metadata_files()
+    main()
